@@ -2,10 +2,10 @@ from os import path, getcwd
 import PySimpleGUI as sg
 
 from .. import __version__, APPNAME
-from ..rexam.rexam_item import RExamItem, RmdFilename
-from ..rexam.file_list import FileListBilingual
+from ..rexam.rmd_file import RmdFile, ENG
+from ..rexam.item_database import ItemFileList
 from ..rexam.r_render import RPY2INSTALLED
-from ..rexam.item_sections import AnswerList
+from ..rexam.item import RExamItem, AnswerList
 from . import dialogs, consts
 from .json_settings import JSONSettings
 from .item_gui import ItemGUI
@@ -73,7 +73,7 @@ class MainWin(object):
                    self.ig_nl.main_frame,
                    self.ig_en.main_frame]]
 
-        self.fl_list = FileListBilingual()
+        self.fl_list = ItemFileList()
         self._unsaved_item = None
 
     def menu_definition(self):
@@ -140,11 +140,8 @@ class MainWin(object):
 
     def select_item_by_filename(self, item_name):
         """select by file name"""
-        idx = self.fl_list.find_filename(item_name,
-                                         second_language=False)
-        if idx is None:
-            idx = self.fl_list.find_filename(item_name,
-                                             second_language=True)
+
+        idx = self.fl_list.find_filename(item_name)
         if idx is not None:
             self.idx_selected_item = idx
 
@@ -165,7 +162,7 @@ class MainWin(object):
             names = self.fl_list.get_shared_names(bilingual_tag=False)
             self.txt_name.update(value=names[self.idx_selected_item])
             self.btn_rename.update(disabled=False)
-            if self.fl_list.is_bilingual(self.idx_selected_item):
+            if self.fl_list.files[self.idx_selected_item].is_bilingual():
                 self.btn_second_lang.update(disabled=True)
             else:
                 self.btn_second_lang.update(disabled=False)
@@ -185,7 +182,7 @@ class MainWin(object):
                 sg.PopupError("No valid item directory selected.")
                 exit()
 
-        self.fl_list = FileListBilingual(self.base_directory)
+        self.fl_list = ItemFileList(self.base_directory)
 
         cnt = self.fl_list.get_count()
         self.fr_items.update(value="{} items".format(cnt["total"]))
@@ -199,14 +196,16 @@ class MainWin(object):
         list_display = self.fl_list.get_shared_names()
         self.lb_items.update(values=list_display)
 
-    def reset_gui(self):
+    def reset_gui(self, select_by_filename=None):
 
-        if self.idx_selected_item is not None:
-            # keep selected
-            selected_file = self.fl_list.files[
-                self.idx_selected_item][0].filename
+        if select_by_filename:
+            selected_file = select_by_filename
         else:
-            selected_file = None
+            try:
+                selected_file = self.fl_list.files[
+                                    self.idx_selected_item].rmd_item.filename
+            except:
+                selected_file = None
 
         self.update_item_list()
         self.ig_nl.rexam_item = None
@@ -220,6 +219,7 @@ class MainWin(object):
         if selected_file is not None:
             self.select_item_by_filename(selected_file)
 
+
     def run(self):
         win = sg.Window("{} ({})".format(APPNAME, __version__),
                         self.layout, finalize=True, return_keyboard_events=True,
@@ -284,22 +284,22 @@ class MainWin(object):
             ig.update_gui()
 
         elif event.endswith("btn_fix_meta_issues"):
-            needs_gui_reset = False
             ig.update_ss_item()
             for i in ig.rexam_item.validate():
-                if str(i.fix_fnc).find("fix_directory_name") >= 0:
-                    needs_gui_reset = True
                 i.fix()
-            if needs_gui_reset:
-                self.reset_gui()
-            else:
-                ig.update_gui()
+                if i.fix_requires_gui_reset:
+                    if isinstance(i.fix_requires_gui_reset, str):
+                        self.reset_gui(select_by_filename=i.fix_requires_gui_reset)
+                    else:
+                        self.reset_gui()
+                    return
+            ig.update_gui()
 
 
     def process_event(self, event, values):
 
         if event == "__TIMEOUT__":
-            if self.fl_list.file_list_changed():
+            if self.fl_list.is_file_list_changed():
                 self.save_items(ask=True, info_text=
                         "Changes in base directory detected.")
                 self.reset_gui()
@@ -351,37 +351,44 @@ class MainWin(object):
 
         elif event == "Raw files":
             try:
-                two_files = self.fl_list.files[self.idx_selected_item]
+                flns = self.fl_list.files[self.idx_selected_item]
             except:
                 return
             self.save_items(ask=True)
-            dialogs.show_text_file(two_files[0], two_files[1])
+            dialogs.show_text_file(flns.rmd_item, flns.rmd_translation)
 
         elif event.endswith("render"):
             try:
-                two_files = self.fl_list.files[self.idx_selected_item]
+                flns = self.fl_list.files[self.idx_selected_item]
             except:
                 return
             if event.startswith("Dutch"):
-                fl = two_files[0]
+                fl = flns.rmd_item
             else:
-                fl = two_files[1]
+                fl = flns.rmd_translation
             if fl is not None:
                 self.save_items(ask=True)
-                dialogs.render(two_files[0])
+                dialogs.render(flns[0])
 
     def load_selected_item(self):
         if self.idx_selected_item is None:
             return
 
-        rexam_items = self.fl_list.load_files(self.idx_selected_item)
-        fls = self.fl_list.files[self.idx_selected_item]
-        if fls[0] is not None and fls[0].language_code == "en":
-            self.ig_nl.rexam_item = rexam_items[1]
-            self.ig_en.rexam_item = rexam_items[0]
-        else:
-            self.ig_nl.rexam_item = rexam_items[0]
-            self.ig_en.rexam_item = rexam_items[1]
+        try:
+            fls = self.fl_list.files[self.idx_selected_item]
+        except:
+            fls = None
+
+        if fls is not None:
+            if not fls.is_bilingual() and fls.rmd_item.language_code == ENG:
+                self.ig_en.rexam_item = RExamItem.load(fls.rmd_item.full_path)
+                self.ig_nl.rexam_item = None
+            else:
+                self.ig_nl.rexam_item = RExamItem.load(fls.rmd_item.full_path)
+                if fls.rmd_translation is not None:
+                    self.ig_en.rexam_item = RExamItem.load(fls.rmd_translation.full_path)
+                else:
+                    self.ig_en.rexam_item = None
 
         self.ig_en.update_gui()
         self.ig_nl.update_gui()
@@ -412,14 +419,14 @@ class MainWin(object):
 
         if new_items[0] is not None:
             self.save_items()
-            fl_name = new_items[0].filename.filename
+            fl_name = new_items[0].filename
             for n in new_items:
                 if n is not None:
                     n.save()
 
             self.ig_nl.rexam_item = new_items[0]
             self.ig_en.rexam_item = new_items[1]
-            if self.ig_nl.rexam_item.filename.language_code == "en":
+            if self.ig_nl.rexam_item.language_code == "en":
                 self.ig_nl.rexam_item, self.ig_en.rexam_item = \
                     self.ig_en.rexam_item, self.ig_nl.rexam_item # swap
             self.update_item_list()
@@ -431,14 +438,14 @@ class MainWin(object):
             self.menu.update(menu_definition=self.menu_definition())
 
     def add_second_language(self):
-            fl = self.fl_list.files[self.idx_selected_item]
-            fl_path = fl[0].get_other_language_path()
+            ifln = self.fl_list.files[self.idx_selected_item].rmd_item
+            fl_path = ifln.get_other_language_path()
             copy_content = sg.popup_yes_no("Copy content of {}?".format(
-                        fl[0].name))
+                        ifln.name))
             if copy_content == "Yes":
-                new_name = RmdFilename(fl_path).name
-                new = fl[0].copy_files(new_name)
-                if not isinstance(new, RmdFilename):
+                new_name = RmdFile(fl_path).name
+                new = ifln.copy_files(new_name)
+                if not isinstance(new, RmdFile):
                     # io error
                     log(new)
                     self.reset_gui()
@@ -452,21 +459,19 @@ class MainWin(object):
         if n1 is not None:
             self.save_items(ask=False)
 
-            add_language = len(n2) and not self.fl_list.is_bilingual(
-                                            self.idx_selected_item) #new and not old is bilingual
+            flns = self.fl_list.files[self.idx_selected_item]
+            add_language = len(n2) and not flns.is_bilingual()
             # rename
             for new_name, old in zip((n1, n2),
-                                     self.fl_list.files[self.idx_selected_item]):
+                                     (flns.rmd_item,
+                                      flns.rmd_translation)):
                 if new_name is not None and old is not None:
                     log(old.rename(new_name, rename_dir=fix_dir,
                                    rename_on_disk=True))
 
             self.reset_gui()
-            self.select_item_by_filename(n1 + RmdFilename.RMDFILE_SUFFIX)
+            self.select_item_by_filename(n1 + RmdFile.SUFFIX)
             if add_language:
                 self.add_second_language()
                 self.reset_gui()
-                self.select_item_by_filename(n1 + RmdFilename.RMDFILE_SUFFIX)
-
-
-# FIXME: ".Rmd" not with capitol R --> not shared filename
\ No newline at end of file
+                self.select_item_by_filename(n1 + RmdFile.SUFFIX)
